@@ -1,5 +1,5 @@
 package ExtUtils::Builder::Planner;
-$ExtUtils::Builder::Planner::VERSION = '0.013';
+$ExtUtils::Builder::Planner::VERSION = '0.014';
 use strict;
 use warnings;
 
@@ -127,7 +127,7 @@ sub run_dsl {
 		}
 	}
 
-	my $path = File::Spec->file_name_is_absolute($filename) ? $filename : File::Spec->catfile(File::Spec->curdir, $filename);
+	my $path = File::Spec->rel2abs($filename);
 	eval "package $dsl_module; my \$ret = do \$path; die \$@ if \$@; defined \$ret || !\$!" or die $@ // Carp::shortmess("Can't run $path: $!");
 	return;
 }
@@ -148,7 +148,7 @@ ExtUtils::Builder::Planner - An ExtUtils::Builder Plan builder
 
 =head1 VERSION
 
-version 0.013
+version 0.014
 
 =head1 SYNOPSIS
 
